@@ -72,6 +72,9 @@ class SSSDOptions(object):
         'shell_fallback': _('If a shell stored in central directory is allowed but not available, use this fallback'),
         'default_shell': _('Shell to use if the provider does not list one'),
         'memcache_timeout': _('How long will be in-memory cache records valid'),
+        'memcache_size_passwd': _('Size (in megabytes) of the data table allocated inside fast in-memory cache for passwd requests'),
+        'memcache_size_group': _('Size (in megabytes) of the data table allocated inside fast in-memory cache for group requests'),
+        'memcache_size_initgroups': _('Size (in megabytes) of the data table allocated inside fast in-memory cache for initgroups requests'),
         'homedir_substring': _('The value of this option will be used in the expansion of the override_homedir option '
                                'if the template contains the format string %H.'),
         'get_domains_timeout': _('Specifies time in seconds for which the list of subdomains will be considered '
@@ -101,6 +104,10 @@ class SSSDOptions(object):
         'p11_wait_for_card_timeout': _('Additional timeout to wait for a card if requested'),
         'p11_uri': _('PKCS#11 URI to restrict the selection of devices for Smartcard authentication'),
         'pam_initgroups_scheme' : _('When shall the PAM responder force an initgroups request'),
+        'pam_gssapi_services' : _('List of PAM services that are allowed to authenticate with GSSAPI.'),
+        'pam_gssapi_check_upn' : _('Whether to match authenticated UPN with target user'),
+        'pam_gssapi_indicators_map' : _('List of pairs <PAM service>:<authentication indicator> that '
+                                        'must be enforced for PAM access with GSSAPI authentication'),
 
         # [sudo]
         'sudo_timed': _('Whether to evaluate the time-based attributes in sudo rules'),
@@ -159,6 +166,9 @@ class SSSDOptions(object):
         'groups': _('A comma-separated list of groups, members of which should have session recording enabled. '
                     'Matches group names as returned by NSS. I.e. after the possible space replacement, case changes, '
                     'etc.'),
+        'exclude_users': _('A comma-separated list of users to be excluded from recording, only when scope=all'),
+        'exclude_groups': _('A comma-separated list of groups, members of which should be excluded from recording, '
+                            ' only when scope=all. '),
 
         # [provider]
         'id_provider': _('Identity provider'),
@@ -174,6 +184,7 @@ class SSSDOptions(object):
 
         # [domain]
         'domain_type': _('Whether the domain is usable by the OS or by applications'),
+        'enabled': _('Enable or disable the domain'),
         'min_id': _('Minimum user ID'),
         'max_id': _('Maximum user ID'),
         'enumerate': _('Enable enumerating all users/groups'),
@@ -315,6 +326,7 @@ class SSSDOptions(object):
         'ad_update_samba_machine_account_password': _('Whether to update the machine account password in the Samba '
                                                       'database'),
         'ad_use_ldaps': _('Use LDAPS port for LDAP and Global Catalog requests'),
+        'ad_allow_remote_domain_local_groups' : _('Do not filter domain local groups from other domains'),
 
         # [provider/krb5]
         'krb5_kdcip': _('Kerberos server address'),
@@ -338,6 +350,7 @@ class SSSDOptions(object):
         'krb5_fast_principal': _("Selects the principal to use for FAST"),
         'krb5_canonicalize': _("Enables principal canonicalization"),
         'krb5_use_enterprise_principal': _("Enables enterprise principals"),
+        'krb5_use_subdomain_realm': _("Enables using of subdomains realms for authentication"),
         'krb5_map_user': _('A mapping from user names to Kerberos principal names'),
 
         # [provider/krb5/chpass]
@@ -480,6 +493,7 @@ class SSSDOptions(object):
         'ldap_max_id': _('Set upper boundary for allowed IDs from the LDAP server'),
         'ldap_pwdlockout_dn': _('DN for ppolicy queries'),
         'wildcard_limit': _('How many maximum entries to fetch during a wildcard request'),
+        'ldap_library_debug_level': _('Set libldap debug level'),
 
         # [provider/ldap/auth]
         'ldap_pwd_policy': _('Policy to evaluate the password expiration'),
